.. This is part of the Photini documentation.
   Copyright (C)  2012-17  Jim Easterbrook.
   See the file ../DOC_LICENSE.txt for copying condidions.

User manual
===========

This manual attempts to cover every part of Photini in detail, but still be usable as a tutorial.
I suggest you read the :doc:`image selector <image_selector>` and :doc:`descriptive metadata <descriptive_metadata>` sections first, then read other sections when you start using the relevant features.

.. toctree::
   :maxdepth: 2

   image_selector
   descriptive_metadata
   technical_metadata
   map
   flickr
   picasa
   facebook
   importer
   video
   configuration
   tags
